==> healthrian_common_support-1.0.30.tar.gz: lib/src/filter/data_filter.dart <==
// ignore_for_file: public_member_api_docs, always_use_package_imports, non_constant_identifier_names, lines_longer_than_80_chars, avoid_positional_boolean_parameters, unused_element

import 'digital_filter.dart';
import 'iir_filter/iir_filter.dart';
import 'lib_constants.dart';

class DataFilter {
  DataFilter(int channel) {
    NUMBER_OF_SIGNAL = channel;
    highPass_01 = List.generate(
      NUMBER_OF_SIGNAL,
      (i) => IIRFilterClass(IIRConstant.IIR_HPF_0_1),
    );
    highPass_005 = List.generate(
      NUMBER_OF_SIGNAL,
      (i) => IIRFilterClass(IIRConstant.IIR_HPF_0_05),
    );
    lowPass_40 = List.generate(
      NUMBER_OF_SIGNAL,
      (i) => IIRFilterClass(IIRConstant.IIR_LPF_40),
    );
    lowPass_100 = List.generate(
      NUMBER_OF_SIGNAL,
      (i) => IIRFilterClass(IIRConstant.IIR_LPF_100),
    );
    bandStop_50 = List.generate(
      NUMBER_OF_SIGNAL,
      (i) => IIRFilterClass(IIRConstant.IIR_BSF_50),
    );
    bandStop_60 = List.generate(
      NUMBER_OF_SIGNAL,
      (i) => IIRFilterClass(IIRConstant.IIR_BSF_60),
    );

    dc_block_filter = List<DigitalFilter>.generate(
      NUMBER_OF_SIGNAL,
      (i) => DigitalFilter(),
    );
    dc_block_filter_001 = List<DigitalFilter>.generate(
      NUMBER_OF_SIGNAL,
      (i) => DigitalFilter(),
    );

    setDefaultFilterFlag();
  }

  late List<IIRFilterClass> highPass_01;
  late List<IIRFilterClass> highPass_005;
  late List<IIRFilterClass> lowPass_40;
  late List<IIRFilterClass> lowPass_100;
  late List<IIRFilterClass> bandStop_50;
  late List<IIRFilterClass> bandStop_60;

  late List<DigitalFilter> dc_block_filter;
  late List<DigitalFilter> dc_block_filter_001;

  late bool flag_IIR_HPF_01;
  late bool flag_IIR_HPF_005;
  late bool flag_IIR_LPF_40;
  late bool flag_IIR_LPF_100;
  late bool flag_IIR_BSF_50;
  late bool flag_IIR_BSF_60;

  int NUMBER_OF_SIGNAL = 0;

  void setDefaultFilterFlag() {
    flag_IIR_HPF_01 = true;
    flag_IIR_HPF_005 = true;
    flag_IIR_LPF_40 = true;
    flag_IIR_LPF_100 = true;
    flag_IIR_BSF_50 = false;
    flag_IIR_BSF_60 = true;
  }

  void setFlagEnable(String HighPass, String LowPass, String BandStop) {
    switch (HighPass) {
      case lib_constants.FILTER_NONE:
        flag_IIR_HPF_01 = false;
        flag_IIR_HPF_005 = false;
        break;
      case lib_constants.FILTER_HIGH_PASS_01:
        flag_IIR_HPF_01 = true;
        flag_IIR_HPF_005 = false;
        break;
      case lib_constants.FILTER_HIGH_PASS_005:
        flag_IIR_HPF_01 = false;
        flag_IIR_HPF_005 = true;
        break;
    }
    switch (LowPass) {
      case lib_constants.FILTER_NONE:
        flag_IIR_LPF_40 = false;
        flag_IIR_LPF_100 = false;
        break;
      case lib_constants.FILTER_LOW_PASS_40:
        flag_IIR_LPF_40 = true;
        flag_IIR_LPF_100 = false;
        break;
      case lib_constants.FILTER_LOW_PASS_100:
        flag_IIR_LPF_40 = false;
        flag_IIR_LPF_100 = true;
        break;
    }

    switch (BandStop) {
      case lib_constants.FILTER_NONE:
        flag_IIR_BSF_50 = false;
        flag_IIR_BSF_60 = false;
        break;
      case lib_constants.FILTER_BAND_STOP_50:
        flag_IIR_BSF_50 = true;
        flag_IIR_BSF_60 = false;
        break;
      case lib_constants.FILTER_BAND_STOP_60:
        flag_IIR_BSF_50 = false;
        flag_IIR_BSF_60 = true;
        break;
      case lib_constants.FILTER_BAND_STOP_50_60:
        flag_IIR_BSF_50 = true;
        flag_IIR_BSF_60 = true;
        break;
    }

    // _clearFilter();
  }

  // void _clearFilter() {
  //   for (final element in highPass_01) {
  //     element.clearValue();
  //   }
  //   for (final element in highPass_005) {
  //     element.clearValue();
  //   }
  //   for (final element in lowPass_40) {
  //     element.clearValue();
  //   }
  //   for (final element in lowPass_100) {
  //     element.clearValue();
  //   }
  //   for (final element in bandStop_50) {
  //     element.clearValue();
  //   }
  //   for (final element in bandStop_60) {
  //     element.clearValue();
  //   }
  // }

  double applyFilter(
    int channel,
    double resultData,
    bool leadState,
  ) {
    var filterResultData = resultData;
    if (leadState) {
      // lead 접촉이 불안정한 상태에서 필터 코드에 노이즈가 들어가면 정상 파형이 보일때까지 delay가 길어서 리드 상태가 정상일때만 필터 코드를 사용
      // filterResultData = dc_block_filter[channel].applyWithDouble(filterResultData);

      filterResultData = highPass_005[channel].apply(filterResultData);
      filterResultData = highPass_01[channel].apply(filterResultData);
      filterResultData = lowPass_40[channel].apply(filterResultData);
      filterResultData = lowPass_100[channel].apply(filterResultData);
      filterResultData = bandStop_60[channel].apply(filterResultData);
    }

    return filterResultData;
  }

  bool _isFilterApply() {
    return (flag_IIR_HPF_01 || flag_IIR_HPF_005) || (flag_IIR_LPF_40 || flag_IIR_LPF_100) || flag_IIR_BSF_50 || flag_IIR_BSF_60;
  }

  String _getCurrentFilterDoctorView() {
    return 'F ${_getBSName()} ${_getHPLPName()}';
  }

  String _getCurrentFilterChart() {
    return '${_getHPLPName()} ${_getBSNameChart()}';
  }

  String _getBSName() {
    return (flag_IIR_BSF_50 && flag_IIR_BSF_60)
        ? '50 ~ 60'
        : flag_IIR_BSF_50
            ? '50~'
            : flag_IIR_BSF_60
                ? '60~'
                : '';
  }

  String _getBSNameChart() {
    return (flag_IIR_BSF_50 && flag_IIR_BSF_60)
        ? '(Notch : 50 ~ 60Hz)'
        : flag_IIR_BSF_50
            ? '(Notch : 50Hz)'
            : flag_IIR_BSF_60
                ? '(Notch : 60Hz)'
                : '';
  }

  String _getHPLPName() {
    bool isFilterApplied;
    var sb = '';

    if (flag_IIR_HPF_01) {
      sb += '0.1';
      isFilterApplied = true;
    } else if (flag_IIR_HPF_005) {
      sb += '0.05';
      isFilterApplied = true;
    } else {
      isFilterApplied = false;
    }

    if ((flag_IIR_HPF_01 || flag_IIR_HPF_005) && (flag_IIR_LPF_40 || flag_IIR_LPF_100)) {
      sb += ' - ';
    }

    if (flag_IIR_LPF_40) {
      sb += '40';
      isFilterApplied |= true;
    } else if (flag_IIR_LPF_100) {
      sb += '100';
      isFilterApplied |= true;
    } else {
      isFilterApplied |= false;
    }

    if (isFilterApplied) sb += ' Hz';

    return sb;
  }
}

==> healthrian_common_support-1.0.31.tar.gz: lib/src/filter/data_filter.dart <==
// ignore_for_file: public_member_api_docs, always_use_package_imports, non_constant_identifier_names, lines_longer_than_80_chars, avoid_positional_boolean_parameters, unused_element

import 'digital_filter.dart';
import 'iir_filter/iir_filter.dart';
import 'lib_constants.dart';

class DataFilter {
  DataFilter(int channel) {
    NUMBER_OF_SIGNAL = channel;
    highPass_005 = List.generate(
      NUMBER_OF_SIGNAL,
      (i) => IIRFilterClass(IIRConstant.IIR_HPF_0_05),
    );
    highPass_01 = List.generate(
      NUMBER_OF_SIGNAL,
      (i) => IIRFilterClass(IIRConstant.IIR_HPF_0_1),
    );
    highPass_05 = List.generate(
      NUMBER_OF_SIGNAL,
      (i) => IIRFilterClass(IIRConstant.IIR_HPF_0_5),
    );
    lowPass_40 = List.generate(
      NUMBER_OF_SIGNAL,
      (i) => IIRFilterClass(IIRConstant.IIR_LPF_40),
    );
    lowPass_100 = List.generate(
      NUMBER_OF_SIGNAL,
      (i) => IIRFilterClass(IIRConstant.IIR_LPF_100),
    );
    bandStop_50 = List.generate(
      NUMBER_OF_SIGNAL,
      (i) => IIRFilterClass(IIRConstant.IIR_BSF_50),
    );
    bandStop_60 = List.generate(
      NUMBER_OF_SIGNAL,
      (i) => IIRFilterClass(IIRConstant.IIR_BSF_60),
    );

    dc_block_filter = List<DigitalFilter>.generate(
      NUMBER_OF_SIGNAL,
      (i) => DigitalFilter(),
    );
    dc_block_filter_001 = List<DigitalFilter>.generate(
      NUMBER_OF_SIGNAL,
      (i) => DigitalFilter(),
    );

    setDefaultFilterFlag();
  }

  late List<IIRFilterClass> highPass_01;
  late List<IIRFilterClass> highPass_05;
  late List<IIRFilterClass> highPass_005;
  late List<IIRFilterClass> lowPass_40;
  late List<IIRFilterClass> lowPass_100;
  late List<IIRFilterClass> bandStop_50;
  late List<IIRFilterClass> bandStop_60;

  late List<DigitalFilter> dc_block_filter;
  late List<DigitalFilter> dc_block_filter_001;

  late bool flag_IIR_HPF_01;
  late bool flag_IIR_HPF_005;
  late bool flag_IIR_LPF_40;
  late bool flag_IIR_LPF_100;
  late bool flag_IIR_BSF_50;
  late bool flag_IIR_BSF_60;

  int NUMBER_OF_SIGNAL = 0;

  void setDefaultFilterFlag() {
    flag_IIR_HPF_01 = true;
    flag_IIR_HPF_005 = true;
    flag_IIR_LPF_40 = true;
    flag_IIR_LPF_100 = true;
    flag_IIR_BSF_50 = false;
    flag_IIR_BSF_60 = true;
  }

  void setFlagEnable(String HighPass, String LowPass, String BandStop) {
    switch (HighPass) {
      case lib_constants.FILTER_NONE:
        flag_IIR_HPF_01 = false;
        flag_IIR_HPF_005 = false;
        break;
      case lib_constants.FILTER_HIGH_PASS_01:
        flag_IIR_HPF_01 = true;
        flag_IIR_HPF_005 = false;
        break;
      case lib_constants.FILTER_HIGH_PASS_005:
        flag_IIR_HPF_01 = false;
        flag_IIR_HPF_005 = true;
        break;
    }
    switch (LowPass) {
      case lib_constants.FILTER_NONE:
        flag_IIR_LPF_40 = false;
        flag_IIR_LPF_100 = false;
        break;
      case lib_constants.FILTER_LOW_PASS_40:
        flag_IIR_LPF_40 = true;
        flag_IIR_LPF_100 = false;
        break;
      case lib_constants.FILTER_LOW_PASS_100:
        flag_IIR_LPF_40 = false;
        flag_IIR_LPF_100 = true;
        break;
    }

    switch (BandStop) {
      case lib_constants.FILTER_NONE:
        flag_IIR_BSF_50 = false;
        flag_IIR_BSF_60 = false;
        break;
      case lib_constants.FILTER_BAND_STOP_50:
        flag_IIR_BSF_50 = true;
        flag_IIR_BSF_60 = false;
        break;
      case lib_constants.FILTER_BAND_STOP_60:
        flag_IIR_BSF_50 = false;
        flag_IIR_BSF_60 = true;
        break;
      case lib_constants.FILTER_BAND_STOP_50_60:
        flag_IIR_BSF_50 = true;
        flag_IIR_BSF_60 = true;
        break;
    }

    // _clearFilter();
  }

  // void _clearFilter() {
  //   for (final element in highPass_01) {
  //     element.clearValue();
  //   }
  //   for (final element in highPass_005) {
  //     element.clearValue();
  //   }
  //   for (final element in lowPass_40) {
  //     element.clearValue();
  //   }
  //   for (final element in lowPass_100) {
  //     element.clearValue();
  //   }
  //   for (final element in bandStop_50) {
  //     element.clearValue();
  //   }
  //   for (final element in bandStop_60) {
  //     element.clearValue();
  //   }
  // }

  double applyFilter(
    int channel,
    double resultData,
    bool leadState,
  ) {
    var filterResultData = resultData;
    if (leadState) {
      // lead 접촉이 불안정한 상태에서 필터 코드에 노이즈가 들어가면 정상 파형이 보일때까지 delay가 길어서 리드 상태가 정상일때만 필터 코드를 사용
      // filterResultData = dc_block_filter[channel].applyWithDouble(filterResultData);
      // filterResultData = highPass_005[channel].apply(filterResultData);
      filterResultData = highPass_05[channel].apply(filterResultData);
      filterResultData = highPass_01[channel].apply(filterResultData);
      filterResultData = lowPass_40[channel].apply(filterResultData);
      filterResultData = lowPass_100[channel].apply(filterResultData);
      filterResultData = bandStop_60[channel].apply(filterResultData);
    }

    return filterResultData;
  }

  bool _isFilterApply() {
    return (flag_IIR_HPF_01 || flag_IIR_HPF_005) || (flag_IIR_LPF_40 || flag_IIR_LPF_100) || flag_IIR_BSF_50 || flag_IIR_BSF_60;
  }

  String _getCurrentFilterDoctorView() {
    return 'F ${_getBSName()} ${_getHPLPName()}';
  }

  String _getCurrentFilterChart() {
    return '${_getHPLPName()} ${_getBSNameChart()}';
  }

  String _getBSName() {
    return (flag_IIR_BSF_50 && flag_IIR_BSF_60)
        ? '50 ~ 60'
        : flag_IIR_BSF_50
            ? '50~'
            : flag_IIR_BSF_60
                ? '60~'
                : '';
  }

  String _getBSNameChart() {
    return (flag_IIR_BSF_50 && flag_IIR_BSF_60)
        ? '(Notch : 50 ~ 60Hz)'
        : flag_IIR_BSF_50
            ? '(Notch : 50Hz)'
            : flag_IIR_BSF_60
                ? '(Notch : 60Hz)'
                : '';
  }

  String _getHPLPName() {
    bool isFilterApplied;
    var sb = '';

    if (flag_IIR_HPF_01) {
      sb += '0.1';
      isFilterApplied = true;
    } else if (flag_IIR_HPF_005) {
      sb += '0.05';
      isFilterApplied = true;
    } else {
      isFilterApplied = false;
    }

    if ((flag_IIR_HPF_01 || flag_IIR_HPF_005) && (flag_IIR_LPF_40 || flag_IIR_LPF_100)) {
      sb += ' - ';
    }

    if (flag_IIR_LPF_40) {
      sb += '40';
      isFilterApplied |= true;
    } else if (flag_IIR_LPF_100) {
      sb += '100';
      isFilterApplied |= true;
    } else {
      isFilterApplied |= false;
    }

    if (isFilterApplied) sb += ' Hz';

    return sb;
  }
}
